###############################################################################
# Organize and check data, make and save both wide and long versions of df.
# 
# Jul 6, 2010
#
# Author: McVey
###############################################################################

############################################
## Setup

require(ggplot2)

############################################
## Get data and inspect
##
## The dataframe in the tutorial data.csv file has time courses
##  for reactions at four temps in three different buffers.
##  Concentration was measured for three responses.
##  At each combination of these factors, 3 reps were run.

rxnDf <- read.csv('data/Tutorial data.csv')

dim(rxnDf)
# [1] 261   7

names(rxnDf)
# [1] "Replicate"   "Buffer"      "Time"        "Temperature" "Ianite"     
# [6] "Zerbene"     "LL"         
  
str(rxnDf)
# 'data.frame':	261 obs. of  7 variables:
#  $ Replicate  : int  1 2 3 1 2 3 1 2 3 1 ...
#  $ Buffer     : Factor w/ 3 levels "A","B","C": 1 1 1 1 1 1 1 1 1 1 ...
#  $ Time       : int  1 1 1 11 11 11 15 15 15 2 ...
#  $ Temperature: int  25 25 25 25 25 25 25 25 25 25 ...
#  $ Ianite     : num  3.12 3.11 3.12 2.85 2.86 2.86 2.78 2.74 2.78 3.06 ...
#  $ Zerbene    : num  3.86 3.85 3.87 3.83 3.87 3.87 3.86 3.86 3.86 3.82 ...
#  $ LL         : num  3.34 3.3 3.35 3.05 3.07 2.95 2.99 2.9 2.77 3.27 ...

table(rxnDf$Buffer, rxnDf$Replicate, exclude=NULL)
#       
#         1  2  3 <NA>
#   A    29 29 29    0
#   B    29 29 29    0
#   C    29 29 29    0
#   <NA>  0  0  0    0

table(rxnDf$Time, rxnDf$Temperature, exclude=NULL)
#       
#        4 25 37 45 <NA>
#   0    9  0  0  0    0
#   1    9  9  9  9    0
#   2    9  9  9  9    0
#   3    9  9  9  9    0
#   5    9  9  9  9    0
#   8    9  9  9  9    0
#   11   9  9  9  9    0
#   15   9  9  9  9    0
#   <NA> 0  0  0  0    0


table(rxnDf$Buffer, rxnDf$Time, exclude=NULL)
#       
#         0  1  2  3  5  8 11 15 <NA>
#   A     3 12 12 12 12 12 12 12    0
#   B     3 12 12 12 12 12 12 12    0
#   C     3 12 12 12 12 12 12 12    0
#   <NA>  0  0  0  0  0  0  0  0    0


###################################################
## Make long version of dataframe

meltDf <- melt(rxnDf, id=c('Replicate','Buffer','Time','Temperature'), measured=c('Ianite','Zerbene','LL'))

dim(meltDf)
# [1] 783   6

longDf <- cast(meltDf, Replicate + Buffer + Time + Temperature + variable ~ ...)

names(longDf)     
# [1] "Replicate"   "Buffer"      "Time"        "Temperature" "variable"   
# [6] "(all)"      

names(longDf) <- c('Replicate','Buffer','Time','Temperature','Response','Concentration')

dim(longDf)
# [1] 783   6

head(longDf)
#   Replicate Buffer Time Temperature Response Concentration
# 1         1      A    0           4   Ianite          3.23
# 2         1      A    0           4  Zerbene          3.87
# 3         1      A    0           4       LL          3.37
# 4         1      A    1           4   Ianite          3.15
# 5         1      A    1           4  Zerbene          3.86
# 6         1      A    1           4       LL          3.40

nrow(longDf) == 3*nrow(rxnDf)
# [1] TRUE

table(longDf$Response, longDf$Buffer, exclude=NULL)
#          
#            A  B  C <NA>
#   Ianite  87 87 87    0
#   Zerbene 87 87 87    0
#   LL      87 87 87    0
#   <NA>     0  0  0    0

save(rxnDf, longDf, file='rdata/reactionData.RData')
