###############################################################################
# Make plots of data and analysis results.
# 
# Jul 6, 2010
#
# Author: McVey
###############################################################################

############################################
## Setup

require(ggplot2)

source('Tools/newPlotFunctions.R')


############################################
## Attach data 

attach('rdata/reactionData.RData')

########
##rxnDf
dim(rxnDf)
# [1] 261   7

names(rxnDf)
# [1] "Replicate"   "Buffer"      "Time"        "Temperature" "Ianite"     
# [6] "Zerbene"     "LL"         

head(rxnDf)
#    Replicate Buffer Time Temperature Ianite Zerbene   LL
# 10         1      A    1          25   3.12    3.86 3.34
# 11         2      A    1          25   3.11    3.85 3.30
# 12         3      A    1          25   3.12    3.87 3.35
# 22         1      A   11          25   2.85    3.83 3.05
# 23         2      A   11          25   2.86    3.87 3.07
# 24         3      A   11          25   2.86    3.87 2.95


########
## longDf

dim(longDf)
# [1] 783   6

names(longDf)
# [1] "Replicate"     "Buffer"        "Time"          "Temperature"  
# [5] "Response"      "Concentration"

head(longDf)
#   Replicate Buffer Time Temperature Response Concentration
# 1         1      A    0           4   Ianite          3.23
# 2         1      A    0           4  Zerbene          3.87
# 3         1      A    0           4       LL          3.37
# 4         1      A    1           4   Ianite          3.15
# 5         1      A    1           4  Zerbene          3.86
# 6         1      A    1           4       LL          3.40


############################
## Basic data plots

bufferCompPlot <- ggplot(data=subset(longDf, Response=='Ianite'),
		aes(x=Time, y=Concentration, color=Buffer)) + 
	facet_grid(. ~ Temperature) +
	errBars(summary='meanSE')

bCp1 <- bufferCompPlot + ylab('Ianite (g/L)')
bCp2 <- bufferCompPlot %+% subset(longDf, Response=='Zerbene') + ylab('Zerbene (g/L)')
bCp3 <- bufferCompPlot %+% subset(longDf, Response=='LL') + ylab('LL (g/L)')

tempCompPlot <- ggplot(data=subset(longDf, Response=='Ianite'),
				aes(x=Time, y=Concentration, color=as.factor(Temperature))) + 
		facet_grid(. ~ Buffer) +
		errBars(summary='meanSE') +
		scale_colour_discrete('Temperature')

tCp1 <- tempCompPlot + ylab('Ianite (g/L)')
tCp2 <- tempCompPlot %+% subset(longDf, Response=='Zerbene') + ylab('Zerbene (g/L)')
tCp3 <- tempCompPlot %+% subset(longDf, Response=='LL') + ylab('LL (g/L)')

responseCompPlot <- ggplot(data=longDf,
		aes(x=Time, y=Concentration, color=Response)) +
		facet_grid(Buffer ~ Temperature, margins=TRUE) +
		errBars(summary='meanSE') 

pairedPlot <- ggplot(data=rxnDf,
		aes(x=Ianite, y=LL, color=Time)) + 
	geom_point() + 
	facet_wrap( ~ Temperature, scales='free') +
	geom_smooth(se=FALSE) +
	geom_abline(yintercept=0, slope=1, color='orange', linetype='dashed')

