# plotFunctions.R
# 
# Functions for use with ggplot
#
# Jun 29, 2009
#
# Author: McVey
###############################################################################


meanSE <- function(y, num=2, ...) {
	means <- mean(y, na.rm=TRUE)
	lengths <- length(y[!is.na(y)])
	ses <- sd(y, na.rm=TRUE)/sqrt(lengths)
	data.frame(y=means, ymin=means-num*ses, ymax=means+num*ses, lengths=lengths)
}

meanSD <- function(y, num=2, ...) {
	means <- mean(y, na.rm=TRUE)
	lengths <- length(y[!is.na(y)])
	ses <- sd(y, na.rm=TRUE)
	data.frame(y=means, ymin=means-num*ses, ymax=means+num*ses, lengths=lengths)
}

medMAD <- function(y, num=2, ...) {
	means <- median(y, na.rm=TRUE)
	lengths <- length(y[!is.na(y)])
	ses <- sqrt(pi/2)*mad(y, na.rm=TRUE)/sqrt(lengths)
	data.frame(y=means, ymin=means-num*ses, ymax=means+num*ses, lengths=lengths)
}

medPerc <- function(y, num=2, ...) {
	means <- median(y, na.rm=TRUE)
	lengths <- length(y[!is.na(y)])
	low <- quantile(y, probs=.025)
	high <- quantile(y, probs=.975)
	data.frame(y=means, ymin=low, ymax=high, lengths=lengths)
}


errBars <- function(summary, width=.5, ...) {
	return(c(stat_summary(fun.data=summary, geom='point', ...), 
					stat_summary(fun.data=summary, geom='errorbar', width=width, ...), 
					stat_summary(fun.data=summary, geom='line', ...)))
}